@@ -1,3 +1,4 @@
+from .atomic import AtomicCheck
 from .basic import Basic
 from .bulk_grant_staff_access import BulkGrantStaffAccess
 from .grant_staff_access import GrantStaffAccess
@@ -5,6 +6,7 @@ from .update_my_field import UpdateMyField
 from .update_my_model import UpdateMyModel
 
 __all__ = [
+    'AtomicCheck',
     'Basic',
     'GrantStaffAccess',
     'BulkGrantStaffAccess',
